@@ -1,7 +1,3 @@
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import unicode_literals
-
 import numpy as np
 
 from scipy.constants import epsilon_0
@@ -92,10 +88,10 @@ def plate_fields(A, B, dx, dz, xc, zc, rotAng, sigplate, sighalf):
             src = DC.sources.Dipole([], np.r_[A, 0.0], np.r_[B, 0.0])
         survey = DC.survey.Survey([src])
         problem = DC.Simulation2DCellCentered(
-            mesh, survey=survey, sigmaMap=mapping, solver=Pardiso, bc_type='Dirichlet'
+            mesh, survey=survey, sigmaMap=mapping, solver=Pardiso
         )
         problem_prim = DC.Simulation2DCellCentered(
-            mesh, survey=survey, sigmaMap=mapping, solver=Pardiso, bc_type='Dirichlet'
+            mesh, survey=survey, sigmaMap=mapping, solver=Pardiso
         )
 
         total_field = problem.fields(mtrue)
