@@ -1,7 +1,3 @@
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import unicode_literals
-
 from discretize import TensorMesh
 from SimPEG import maps, SolverLU, utils
 from SimPEG.utils import ExtractCoreMesh
