@@ -1,7 +1,3 @@
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import unicode_literals
-
 import numpy as np
 from scipy.interpolate import griddata, LinearNDInterpolator
 
@@ -10,6 +6,7 @@ from ipywidgets import (
     IntSlider,
     FloatSlider,
     FloatText,
+    BoundedFloatText,
     ToggleButtons,
     VBox,
 )
@@ -55,7 +52,7 @@ class ParametricCircleLayerMap(IdentityMap):
             sig1, sig2, sig3 = np.exp(sig1), np.exp(sig2), np.exp(sig3)
         sigma = np.ones(mesh.nC) * sig1
         sigma[mesh.gridCC[:, 1] < zh] = sig2
-        blkind = utils.ModelBuilder.getIndicesSphere(np.r_[x, zc], r, mesh.gridCC)
+        blkind = utils.model_builder.getIndicesSphere(np.r_[x, zc], r, mesh.gridCC)
         sigma[blkind] = sig3
         return sigma
 
@@ -115,7 +112,7 @@ def DC2Dsurvey(flag="PolePole"):
     for i in range(ntx):
         if flag == "PoleDipole":
             A = np.r_[xr[i], zloc]
-            B = np.r_[mesh.vectorCCx.min(), zloc]
+            B = np.r_[mesh.cell_centers_x.min(), zloc]
             if i < ntx - nmax + 1:
                 M = np.c_[xr[i + 1 : i + 1 + nmax], np.ones(nmax) * zloc]
                 N = np.c_[xr[i + 2 : i + 2 + nmax], np.ones(nmax) * zloc]
@@ -127,11 +124,11 @@ def DC2Dsurvey(flag="PolePole"):
             B = np.r_[xr[i + 1], zloc]
             if i < ntx - nmax + 1:
                 M = np.c_[xr[i + 2 : i + 2 + nmax], np.ones(nmax) * zloc]
-                N = np.c_[np.ones(nmax) * mesh.vectorCCx.max(), np.ones(nmax) * zloc]
+                N = np.c_[np.ones(nmax) * mesh.cell_centers_x.max(), np.ones(nmax) * zloc]
             else:
                 M = np.c_[xr[i + 2 : ntx + 2], np.ones(ntx - i) * zloc]
                 N = np.c_[
-                    np.ones(ntx - i) * mesh.vectorCCx.max(), np.ones(ntx - i) * zloc
+                    np.ones(ntx - i) * mesh.cell_centers_x.max(), np.ones(ntx - i) * zloc
                 ]
         elif flag == "DipoleDipole":
             A = np.r_[xr[i], zloc]
@@ -153,15 +150,15 @@ def DC2Dsurvey(flag="PolePole"):
                 N = np.c_[xr[i + 3 : len(xr)], np.ones(len(xr[i + 3 : len(xr)])) * zloc]
         elif flag == "PolePole":
             A = np.r_[xr[i], zloc]
-            B = np.r_[mesh.vectorCCx.min(), zloc]
+            B = np.r_[mesh.cell_centers_x.min(), zloc]
 
             if i < ntx - nmax + 1:
                 M = np.c_[xr[i + 2 : i + 2 + nmax], np.ones(nmax) * zloc]
-                N = np.c_[np.ones(nmax) * mesh.vectorCCx.max(), np.ones(nmax) * zloc]
+                N = np.c_[np.ones(nmax) * mesh.cell_centers_x.max(), np.ones(nmax) * zloc]
             else:
                 M = np.c_[xr[i + 2 : ntx + 2], np.ones(ntx - i) * zloc]
                 N = np.c_[
-                    np.ones(ntx - i) * mesh.vectorCCx.max(), np.ones(ntx - i) * zloc
+                    np.ones(ntx - i) * mesh.cell_centers_x.max(), np.ones(ntx - i) * zloc
                 ]
 
         rx = DC.receivers.Dipole(M, N)
@@ -677,14 +674,14 @@ def DC2DPseudoWidgetWrapper(rhohalf, rhosph, xc, zc, r, surveyType):
 def DC2DPseudoWidget():
     return interactive(
         DC2DPseudoWidgetWrapper,
-        rhohalf=FloatText(
+        rhohalf=BoundedFloatText(
             min=10,
             max=1000,
             value=1000,
             continuous_update=False,
             description="$\\rho_1$",
         ),
-        rhosph=FloatText(
+        rhosph=BoundedFloatText(
             min=10,
             max=1000,
             value=1000,
@@ -736,14 +733,14 @@ def DC2DfwdWidget():
     return widgetify(
         DC2DfwdWrapper,
         manual=False,
-        rhohalf=FloatText(
+        rhohalf=BoundedFloatText(
             min=10,
             max=1000,
             value=1000,
             continuous_update=False,
             description="$\\rho_1$",
         ),
-        rhosph=FloatText(
+        rhosph=BoundedFloatText(
             min=10,
             max=1000,
             value=500,
