@@ -1,7 +1,3 @@
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import unicode_literals
-
 import numpy as np
 
 import matplotlib
@@ -18,7 +14,7 @@ from SimPEG import maps, utils
 from SimPEG.utils import ExtractCoreMesh, mkvc
 from SimPEG.electromagnetics.static import resistivity as DC
 
-from ipywidgets import interact, IntSlider, FloatSlider, FloatText, ToggleButtons
+from ipywidgets import interact, IntSlider, FloatSlider, FloatText, ToggleButtons, BoundedFloatText
 
 from ..base import widgetify
 
@@ -92,10 +88,10 @@ def cylinder_fields(A, B, r, sigcyl, sighalf, xc=0.0, zc=-20.0):
 
         # make two simulations for the seperate field objects
         sim_primary = DC.Simulation2DCellCentered(
-            mesh, survey=survey, sigmaMap=sigmaMap, solver=Pardiso, bc_type='Dirichlet'
+            mesh, survey=survey, sigmaMap=sigmaMap, solver=Pardiso
         )
         sim_total = DC.Simulation2DCellCentered(
-            mesh, survey=survey, sigmaMap=sigmaMap, solver=Pardiso, bc_type='Dirichlet'
+            mesh, survey=survey, sigmaMap=sigmaMap, solver=Pardiso
         )
 
         primary_field = sim_primary.fields(mhalf)
@@ -706,14 +702,14 @@ def cylinder_app():
             options=["Dipole-Dipole", "Dipole-Pole", "Pole-Dipole", "Pole-Pole"],
             value="Dipole-Dipole",
         ),
-        rhocyl=FloatText(
+        rhocyl=BoundedFloatText(
             min=1e-8,
             max=1e8,
             value=500.0,
             continuous_update=False,
             description="$\\rho_2$",
         ),
-        rhohalf=FloatText(
+        rhohalf=BoundedFloatText(
             min=1e-8,
             max=1e8,
             value=500.0,
