@@ -1,8 +1,3 @@
-from __future__ import division
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import unicode_literals
-
 import numpy as np
 from scipy.constants import mu_0, pi, epsilon_0
 from scipy.special import erf
@@ -40,7 +35,7 @@ def E_from_ElectricDipoleWholeSpace(
     epsilon = epsilon_0 * epsr
     sig_hat = sig + 1j * omega(f) * epsilon
 
-    XYZ = utils.asArray_N_x_Dim(XYZ, 3)
+    XYZ = utils.as_array_n_by_ndim(XYZ, 3)
     # Check
     if XYZ.shape[0] > 1 & f.shape[0] > 1:
         raise Exception(
@@ -101,7 +96,7 @@ def E_galvanic_from_ElectricDipoleWholeSpace(
     epsilon = epsilon_0 * epsr
     sig_hat = sig + 1j * omega(f) * epsilon
 
-    XYZ = utils.asArray_N_x_Dim(XYZ, 3)
+    XYZ = utils.as_array_n_by_ndim(XYZ, 3)
     # Check
     if XYZ.shape[0] > 1 & f.shape[0] > 1:
         raise Exception(
@@ -162,7 +157,7 @@ def E_inductive_from_ElectricDipoleWholeSpace(
     epsilon = epsilon_0 * epsr
     sig_hat = sig + 1j * omega(f) * epsilon
 
-    XYZ = utils.asArray_N_x_Dim(XYZ, 3)
+    XYZ = utils.as_array_n_by_ndim(XYZ, 3)
     # Check
     if XYZ.shape[0] > 1 & f.shape[0] > 1:
         raise Exception(
@@ -332,7 +327,7 @@ def H_from_ElectricDipoleWholeSpace(
     """
     mu = mu_0 * (1 + kappa)
     epsilon = epsilon_0 * epsr
-    XYZ = utils.asArray_N_x_Dim(XYZ, 3)
+    XYZ = utils.as_array_n_by_ndim(XYZ, 3)
     # Check
     if XYZ.shape[0] > 1 & f.shape[0] > 1:
         raise Exception(
@@ -431,7 +426,7 @@ def A_from_ElectricDipoleWholeSpace(
     """
     mu = mu_0 * (1 + kappa)
     epsilon = epsilon_0 * epsr
-    XYZ = utils.asArray_N_x_Dim(XYZ, 3)
+    XYZ = utils.as_array_n_by_ndim(XYZ, 3)
     # Check
     if XYZ.shape[0] > 1 & f.shape[0] > 1:
         raise Exception(
@@ -488,7 +483,7 @@ def E_from_MagneticDipoleWholeSpace(
     epsilon = epsilon_0 * epsr
     m = current * loopArea
 
-    XYZ = utils.asArray_N_x_Dim(XYZ, 3)
+    XYZ = utils.as_array_n_by_ndim(XYZ, 3)
     # Check
     if XYZ.shape[0] > 1 & f.shape[0] > 1:
         raise Exception(
@@ -586,7 +581,7 @@ def H_from_MagneticDipoleWholeSpace(
     epsilon = epsilon_0 * epsr
     m = current * loopArea
 
-    XYZ = utils.asArray_N_x_Dim(XYZ, 3)
+    XYZ = utils.as_array_n_by_ndim(XYZ, 3)
     # Check
     if XYZ.shape[0] > 1 & f.shape[0] > 1:
         raise Exception(
@@ -684,7 +679,7 @@ def F_from_MagneticDipoleWholeSpace(
     epsilon = epsilon_0 * epsr
     m = current * loopArea
 
-    XYZ = utils.asArray_N_x_Dim(XYZ, 3)
+    XYZ = utils.as_array_n_by_ndim(XYZ, 3)
     # Check
     if XYZ.shape[0] > 1 & f.shape[0] > 1:
         raise Exception(
