@@ -1,7 +1,3 @@
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import unicode_literals
-
 import numpy as np
 from SimPEG.electromagnetics.utils import waveform_utils
 import matplotlib.pyplot as plt
