@@ -179,9 +179,9 @@ class PlotTDEM(object):
     def __init__(self, **kwargs):
         super(PlotTDEM, self).__init__()
         utils.setKwargs(self, **kwargs)
-        self.xmin, self.xmax = self.mesh.vectorCCx.min(), self.mesh.vectorCCx.max()
-        self.ymin, self.ymax = self.mesh.vectorCCy.min(), self.mesh.vectorCCy.max()
-        self.zmin, self.zmax = self.mesh.vectorCCz.min(), self.mesh.vectorCCz.max()
+        self.xmin, self.xmax = self.mesh.cell_centers_x.min(), self.mesh.cell_centers_x.max()
+        self.ymin, self.ymax = self.mesh.cell_centers_y.min(), self.mesh.cell_centers_y.max()
+        self.zmin, self.zmax = self.mesh.cell_centers_z.min(), self.mesh.cell_centers_z.max()
 
     def show_3d_survey_geometry(self, elev, azim):
         X1, X2 = -250.0, 250.0
@@ -240,22 +240,22 @@ class PlotTDEM(object):
     def getSlices(self, mesh, vec, itime, normal="Z", loc=0.0, isz=False, isy=False):
         VEC = vec[:, itime].reshape((mesh.nC, 3), order="F")
         if normal == "Z":
-            ind = np.argmin(abs(mesh.vectorCCz - loc))
-            vx = VEC[:, 0].reshape((mesh.nCx, mesh.nCy, mesh.nCz), order="F")[:, :, ind]
-            vy = VEC[:, 1].reshape((mesh.nCx, mesh.nCy, mesh.nCz), order="F")[:, :, ind]
-            vz = VEC[:, 2].reshape((mesh.nCx, mesh.nCy, mesh.nCz), order="F")[:, :, ind]
-            xy = utils.ndgrid(mesh.vectorCCx, mesh.vectorCCy)
+            ind = np.argmin(abs(mesh.cell_centers_z - loc))
+            vx = VEC[:, 0].reshape((mesh.shape_cells[0], mesh.mesh.shape_cells[1], mesh.mesh.shape_cells[2]), order="F")[:, :, ind]
+            vy = VEC[:, 1].reshape((mesh.shape_cells[0], mesh.mesh.shape_cells[1], mesh.mesh.shape_cells[2]), order="F")[:, :, ind]
+            vz = VEC[:, 2].reshape((mesh.shape_cells[0], mesh.mesh.shape_cells[1], mesh.mesh.shape_cells[2]), order="F")[:, :, ind]
+            xy = utils.ndgrid(mesh.cell_centers_x, mesh.cell_centers_y)
             if isz:
                 return utils.mkvc(vz), xy
             else:
                 return np.c_[utils.mkvc(vx), utils.mkvc(vy)], xy
 
         elif normal == "Y":
-            ind = np.argmin(abs(mesh.vectorCCx - loc))
-            vx = VEC[:, 0].reshape((mesh.nCx, mesh.nCy, mesh.nCz), order="F")[:, ind, :]
-            vy = VEC[:, 1].reshape((mesh.nCx, mesh.nCy, mesh.nCz), order="F")[:, ind, :]
-            vz = VEC[:, 2].reshape((mesh.nCx, mesh.nCy, mesh.nCz), order="F")[:, ind, :]
-            xz = utils.ndgrid(mesh.vectorCCx, mesh.vectorCCz)
+            ind = np.argmin(abs(mesh.cell_centers_x - loc))
+            vx = VEC[:, 0].reshape((mesh.shape_cells[0], mesh.mesh.shape_cells[1], mesh.mesh.shape_cells[2]), order="F")[:, ind, :]
+            vy = VEC[:, 1].reshape((mesh.shape_cells[0], mesh.mesh.shape_cells[1], mesh.mesh.shape_cells[2]), order="F")[:, ind, :]
+            vz = VEC[:, 2].reshape((mesh.shape_cells[0], mesh.mesh.shape_cells[1], mesh.mesh.shape_cells[2]), order="F")[:, ind, :]
+            xz = utils.ndgrid(mesh.cell_centers_x, mesh.cell_centers_z)
             if isz:
                 return utils.mkvc(vz), xz
             elif isy:
@@ -264,11 +264,11 @@ class PlotTDEM(object):
                 return np.c_[utils.mkvc(vx), utils.mkvc(vz)], xz
 
         elif normal == "X":
-            ind = np.argmin(abs(mesh.vectorCCy - loc))
-            vx = VEC[:, 0].reshape((mesh.nCx, mesh.nCy, mesh.nCz), order="F")[ind, :, :]
-            vy = VEC[:, 1].reshape((mesh.nCx, mesh.nCy, mesh.nCz), order="F")[ind, :, :]
-            vz = VEC[:, 2].reshape((mesh.nCx, mesh.nCy, mesh.nCz), order="F")[ind, :, :]
-            yz = utils.ndgrid(mesh.vectorCCy, mesh.vectorCCz)
+            ind = np.argmin(abs(mesh.cell_centers_y - loc))
+            vx = VEC[:, 0].reshape((mesh.shape_cells[0], mesh.mesh.shape_cells[1], mesh.mesh.shape_cells[2]), order="F")[ind, :, :]
+            vy = VEC[:, 1].reshape((mesh.shape_cells[0], mesh.mesh.shape_cells[1], mesh.mesh.shape_cells[2]), order="F")[ind, :, :]
+            vz = VEC[:, 2].reshape((mesh.shape_cells[0], mesh.mesh.shape_cells[1], mesh.mesh.shape_cells[2]), order="F")[ind, :, :]
+            yz = utils.ndgrid(mesh.cell_centers_y, mesh.cell_centers_z)
             if isz:
                 return utils.mkvc(vy), yz
             elif isy:
