@@ -1,6 +1,3 @@
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import unicode_literals
 import numpy as np
 from ipywidgets import widgets
 from mpl_toolkits.mplot3d import Axes3D
