@@ -131,7 +131,7 @@ class TomographyInversionApp(object):
     def get_block_index(self, xc=50, yc=50, dx=20, dy=20):
         p0 = np.array([xc - dx / 2.0, yc + dy / 2])
         p1 = np.array([xc + dx / 2.0, yc - dy / 2])
-        index = utils.ModelBuilder.getIndicesBlock(p0, p1, self.mesh_prop.gridCC)
+        index = utils.model_builder.getIndicesBlock(p0, p1, self.mesh_prop.gridCC)
         return index
 
     def get_block_points(self, xc=50, yc=50, dx=20, dy=20):
